@@ -3,14 +3,14 @@ package Lemonldap::NG::Portal::AuthSSL;
 use strict;
 use Lemonldap::NG::Portal::Simple;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # Authentication is made by Apache with SSL and here before searching the LDAP
 # Directory.
 # So authenticate is overloaded to return only PE_OK.
 
 our $OVERRIDE = {
-    # By default, authentication is valid if SSL_CLIENT_S_DN_Email environement
+    # By default, authentication is valid if SSL_CLIENT_S_DN_Email environment
     # variable is present. Adapt it if you want
     extractFormInfo => sub {
         my $self = shift;
@@ -97,7 +97,8 @@ See L<Lemonldap::NG::Portal::Simple> for usage and other methods.
 
 =head1 SEE ALSO
 
-L<Lemonldap::NG::Portal>, L<Lemonldap::NG::Portal::Simple>
+L<Lemonldap::NG::Portal>, L<Lemonldap::NG::Portal::Simple>,
+http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation
 
 =head1 AUTHOR
 
